@@ -38,6 +38,9 @@ def bpreg_for_directory(
     if input_dirpath == "": 
         raise ValueError("Input path is not defined. Please define the input path via -i <input_path>.")
 
+    if output_dirpath == "": 
+        raise ValueError("Output path is not defined. Please define the output path via -o <output_path>.")
+
     ifiles = [f for f in os.listdir(input_dirpath) if f.endswith((".nii.gz", ".nii"))]
     ofiles = [f.replace(".nii", "").replace(".gz", "") + ".json" for f in ifiles]
 
@@ -57,8 +60,8 @@ def bpreg_for_directory(
 def plot_scores_in_json_files(output_path): 
     json_files = [f for f in os.listdir(output_path) if f.endswith(".json")]
     for file in json_files: 
-        save_path = output_path + file.replace(".json", ".png")
-        plot_scores(output_path + file, save_path=save_path)
+        save_path = os.path.join(output_path, file.replace(".json", ".png"))
+        plot_scores(os.path.join(output_path, file), save_path=save_path)
 
 def bpreg_inference(
     input_path: str,
